@@ -44,6 +44,7 @@ class AuthScope(Enum):
     :var CHANNEL_MANAGE_VIDEOS:
     :var USER_READ_BLOCKED_USERS:
     :var USER_MANAGE_BLOCKED_USERS:
+    :var USER_READ_SUBSCRIPTIONS:
     """
     ANALYTICS_READ_EXTENSION = 'analytics:read:extensions'
     ANALYTICS_READ_GAMES = 'analytics:read:games'
@@ -72,6 +73,7 @@ class AuthScope(Enum):
     CHANNEL_MANAGE_VIDEOS = 'channel:manage:videos'
     USER_READ_BLOCKED_USERS = 'user:read:blocked_users'
     USER_MANAGE_BLOCKED_USERS = 'user:manage:blocked_users'
+    USER_READ_SUBSCRIPTIONS = 'user:read:subscriptions'
 
 
 class ModerationEventType(Enum):
@@ -153,6 +155,7 @@ class AuthType(Enum):
     NONE = 0
     USER = 1
     APP = 2
+    EITHER = 3
 
 
 class CodeStatus(Enum):
@@ -248,6 +251,11 @@ class InvalidRefreshTokenException(TwitchAPIException):
     pass
 
 
+class InvalidTokenException(TwitchAPIException):
+    """Used if a invalid token is set for the client"""
+    pass
+
+
 class NotFoundException(TwitchAPIException):
     """Resource was not found with the given parameter"""
     pass
@@ -276,3 +284,8 @@ class TwitchBackendException(TwitchAPIException):
 class PubSubListenTimeoutException(TwitchAPIException):
     """when a a PubSub listen command times out"""
     pass
+
+
+class MissingAppSecretException(TwitchAPIException):
+    """When the app secret is not set but app authorization is attempted"""
+    pass
